aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJakub Adamek <jakuba@google.com>2016-01-26 12:17:05 +0000
committerJakub Adamek <jakuba@google.com>2016-01-26 12:17:05 +0000
commit59dd956d1271d728fa1187b4024edc78eef6e587 (patch)
tree44ceeeffba947365b6f65a0710fc3f94ae28105e
parenteedc65a59bf96c2075b7feecae6c5fd1d3713e9e (diff)
downloadandroid_external_proguard-59dd956d1271d728fa1187b4024edc78eef6e587.tar.gz
android_external_proguard-59dd956d1271d728fa1187b4024edc78eef6e587.tar.bz2
android_external_proguard-59dd956d1271d728fa1187b4024edc78eef6e587.zip
Increase GC limit for proguard to 2G.
Bug: 26555886 Change-Id: I9045628003e69b50bb50d71253729e7e525f57e3
-rwxr-xr-xbin/proguard.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/proguard.sh b/bin/proguard.sh
index bd7e0b6..dfc8b23 100755
--- a/bin/proguard.sh
+++ b/bin/proguard.sh
@@ -21,6 +21,6 @@ fi
PROGUARD_HOME=`dirname "$PROGUARD"`/..
-# BEGIN android-changed Added -Xmx512M for Mac builds
-java -Xmx512M -jar "$PROGUARD_HOME/lib/proguard.jar" "$@"
+# BEGIN android-changed Added -Xmx2G for Mac builds
+java -Xmx2G -jar "$PROGUARD_HOME/lib/proguard.jar" "$@"
# END android-changed